from pathlib import Path
from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker, declarative_base
from sqlalchemy.ext.declarative import DeclarativeMeta

# Create database directory
DB_DIR = Path("/app") / "storage" / "db"
DB_DIR.mkdir(parents=True, exist_ok=True)

# SQLite database URL
SQLALCHEMY_DATABASE_URL = f"sqlite:///{DB_DIR}/db.sqlite"

# Create SQLAlchemy engine with SQLite-specific connection arguments
engine = create_engine(
    SQLALCHEMY_DATABASE_URL,
    connect_args={"check_same_thread": False}
)

# Create a SessionLocal class
SessionLocal = sessionmaker(autocommit=False, autoflush=False, bind=engine)

# Create a Base class for declarative models
Base: DeclarativeMeta = declarative_base()

def init_db() -> None:
    """Initialize database by creating all tables."""
    Base.metadata.create_all(bind=engine)

def get_db():
    """Dependency function for getting database session."""
    db = SessionLocal()
    try:
        yield db
    finally:
        db.close()